import os
import subprocess

from django.core.management.base import BaseCommand
from django.conf import settings

from scrutiny.projects.models import Module


class Command(BaseCommand):
    help = 'Create checkouts of modules'

    def handle(self, *args, **options):
        checkouts_directory = os.path.join(settings.MEDIA_ROOT, 'src')
        if not os.path.exists(checkouts_directory):
            os.mkdir(checkouts_directory)

        for module in Module.objects.all():
            if not module.repository_url:
                continue

            checkout_dir = os.path.join(checkouts_directory, module.name)

            kws = {}
            kws['stdout'] = subprocess.PIPE
            kws['stderr'] = subprocess.STDOUT
            if not os.path.exists(checkout_dir):
                # full clone
                cmd = ['git', 'clone', module.repository_url, module.name]
                kws['cwd'] = checkouts_directory
            else:
                # pull
                cmd = ['git', 'pull']
                kws['cwd'] = checkout_dir

            p = subprocess.Popen(cmd, **kws)
            p.communicate()
            p.wait()
